Coverage for arrakis_server/constants.py: 100.0%

1# Copyright (c) 2022, California Institute of Technology and contributors

2#

3# You should have received a copy of the licensing terms for this

4# software included in the file "LICENSE" located in the top-level

5# directory of this package. If you did not, you can view a copy at

6# https://git.ligo.org/ngdd/arrakis-python/-/raw/main/LICENSE

7

8

9 DEFAULT_LOCATION = "grpc://0.0.0.0:31206"

10

11 FLIGHT_REUSE_URL = "arrow-flight-reuse-connection://?"